import pandas as pd

@staticmethod
def dfGroup(dfSource,by=None,columnsList=None,groupbyColumns=None,floatFormatter='{:.2f}',aggDict=None,adjustNames=True):    
    if by != 'agg':
        if columnsList!= None:
            dataFrame = dfSource[columnsList]
            if by == 'mean':
                dataFrame = dataFrame.groupby(groupbyColumns).mean()
            elif by == 'min':
                dataFrame = dataFrame.groupby(groupbyColumns).min()
            elif by == 'max':
                dataFrame = dataFrame.groupby(groupbyColumns).max()
            elif by == 'std':
                dataFrame = dataFrame.groupby(groupbyColumns).std()
            elif by == 'var':
                dataFrame = dataFrame.groupby(groupbyColumns).var()
            elif by == 'count':
                dataFrame = dataFrame.groupby(groupbyColumns).count()
            dataFrame = dataFrame.groupby(groupbyColumns).mean()
            dataFrame = dataFrame.reset_index()
            if adjustNames != False:
                for t in dataFrame.columns:
                    if t in groupbyColumns:
                        pass
                    else:
                        dataFrame = dataFrame.rename({t:f'{t}_mean '},axis=1)
            for i in (dataFrame.columns):
                if dataFrame[i].dtypes == 'float64':
                    dataFrame.loc[:, i] = dataFrame[i].map(floatFormatter.format)
        else:
            dataFrame = dfSource
            if by == 'mean':
                dataFrame = dataFrame.groupby(groupbyColumns).mean()
            elif by == 'min':
                dataFrame = dataFrame.groupby(groupbyColumns).min()
            elif by == 'max':
                dataFrame = dataFrame.groupby(groupbyColumns).max()
            elif by == 'std':
                dataFrame = dataFrame.groupby(groupbyColumns).std()
            elif by == 'var':
                dataFrame = dataFrame.groupby(groupbyColumns).var()
            elif by == 'count':
                dataFrame = dataFrame.groupby(groupbyColumns).count()
            dataFrame = dataFrame.reset_index()
            if adjustNames != False:
                for t in dataFrame.columns:
                    if t in groupbyColumns:
                        pass
                    else:
                        dataFrame = dataFrame.rename({t:f'{t}_mean '},axis=1)
            if floatFormatter != None:
                for i in (dataFrame.columns):
                    if dataFrame[i].dtypes == 'float64':
                        dataFrame.loc[:, i] = dataFrame[i].map(floatFormatter.format)
            else:
                pass
    elif by == 'agg':
        dataFrame = dfSource
        dataFrame = dataFrame.groupby(groupbyColumns).agg(aggDict)
        dataFrame = dataFrame.reset_index()
        dataFrame = dataFrame.rename({},axis=1)
        if adjustNames != False:
            for t in dataFrame.columns:
                if t in aggDict:
                    dataFrame = dataFrame.rename({t:f'{t}_{aggDict[t]}'},axis=1)
        else:
            pass
        if floatFormatter != None:
            for i in (dataFrame.columns):
                    if dataFrame[i].dtypes == 'float64':
                        dataFrame.loc[:, i] = dataFrame[i].map(floatFormatter.format)
        else:
            pass
    return dataFrame



from distutils.core import setup
setup(
  name = 'ez_pd',         # How you named your package folder (MyLib)
  packages = ['ez_pd'],   # Chose the same as "name"
  version = '1.2',      # Start with a small number and increase it with every change you make
  license='MIT',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
  description = 'This is a package to make it easier to use pandas for bundling',   # Give a short description about your library
  author = 'Fabian Matus',                   # Type in your name
  author_email = 'fabiax.e.m10@gmail.com',      # Type in your E-Mail
  url = 'https://https://github.com/fabi-ignacio',   # Provide either the link to your github or to your website
  download_url = 'https://github.com/fabi-ignacio/ez-pandas/archive/refs/tags/v1.2.tar.gz',    # I explain this later on
  keywords = ['SOME', 'MEANINGFULL', 'KEYWORDS'],   # Keywords that define your package best
  install_requires=[            # I get to this in a second
          'pandas',
      ],
  classifiers=[
    'Intended Audience :: Developers',      # Define that your audience are developers
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',   # Again, pick a license
    'Programming Language :: Python :: 3.10',
  ],
)